# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetPrivateDataSourceConnectNetworksResult',
    'AwaitableGetPrivateDataSourceConnectNetworksResult',
    'get_private_data_source_connect_networks',
    'get_private_data_source_connect_networks_output',
]

@pulumi.output_type
class GetPrivateDataSourceConnectNetworksResult:
    """
    A collection of values returned by getPrivateDataSourceConnectNetworks.
    """
    def __init__(__self__, id=None, name_filter=None, private_data_source_connect_networks=None, region_filter=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name_filter and not isinstance(name_filter, str):
            raise TypeError("Expected argument 'name_filter' to be a str")
        pulumi.set(__self__, "name_filter", name_filter)
        if private_data_source_connect_networks and not isinstance(private_data_source_connect_networks, list):
            raise TypeError("Expected argument 'private_data_source_connect_networks' to be a list")
        pulumi.set(__self__, "private_data_source_connect_networks", private_data_source_connect_networks)
        if region_filter and not isinstance(region_filter, str):
            raise TypeError("Expected argument 'region_filter' to be a str")
        pulumi.set(__self__, "region_filter", region_filter)

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The ID of this datasource. This is an internal identifier used by the provider to track this datasource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="nameFilter")
    def name_filter(self) -> Optional[str]:
        return pulumi.get(self, "name_filter")

    @property
    @pulumi.getter(name="privateDataSourceConnectNetworks")
    def private_data_source_connect_networks(self) -> Sequence['outputs.GetPrivateDataSourceConnectNetworksPrivateDataSourceConnectNetworkResult']:
        return pulumi.get(self, "private_data_source_connect_networks")

    @property
    @pulumi.getter(name="regionFilter")
    def region_filter(self) -> Optional[str]:
        return pulumi.get(self, "region_filter")


class AwaitableGetPrivateDataSourceConnectNetworksResult(GetPrivateDataSourceConnectNetworksResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetPrivateDataSourceConnectNetworksResult(
            id=self.id,
            name_filter=self.name_filter,
            private_data_source_connect_networks=self.private_data_source_connect_networks,
            region_filter=self.region_filter)


def get_private_data_source_connect_networks(name_filter: Optional[str] = None,
                                             region_filter: Optional[str] = None,
                                             opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetPrivateDataSourceConnectNetworksResult:
    """
    Fetches Private Data source Connect networks from Grafana Cloud.

    * [Official documentation](https://grafana.com/docs/grafana-cloud/security-and-account-management/authentication-and-permissions/access-policies/)
    * [API documentation](https://grafana.com/docs/grafana-cloud/developer-resources/api-reference/cloud-api/#list-access-policies)

    Required access policy scopes:

    * accesspolicies:read
    """
    __args__ = dict()
    __args__['nameFilter'] = name_filter
    __args__['regionFilter'] = region_filter
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('grafana:cloud/getPrivateDataSourceConnectNetworks:getPrivateDataSourceConnectNetworks', __args__, opts=opts, typ=GetPrivateDataSourceConnectNetworksResult).value

    return AwaitableGetPrivateDataSourceConnectNetworksResult(
        id=pulumi.get(__ret__, 'id'),
        name_filter=pulumi.get(__ret__, 'name_filter'),
        private_data_source_connect_networks=pulumi.get(__ret__, 'private_data_source_connect_networks'),
        region_filter=pulumi.get(__ret__, 'region_filter'))
def get_private_data_source_connect_networks_output(name_filter: Optional[pulumi.Input[Optional[str]]] = None,
                                                    region_filter: Optional[pulumi.Input[Optional[str]]] = None,
                                                    opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetPrivateDataSourceConnectNetworksResult]:
    """
    Fetches Private Data source Connect networks from Grafana Cloud.

    * [Official documentation](https://grafana.com/docs/grafana-cloud/security-and-account-management/authentication-and-permissions/access-policies/)
    * [API documentation](https://grafana.com/docs/grafana-cloud/developer-resources/api-reference/cloud-api/#list-access-policies)

    Required access policy scopes:

    * accesspolicies:read
    """
    __args__ = dict()
    __args__['nameFilter'] = name_filter
    __args__['regionFilter'] = region_filter
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('grafana:cloud/getPrivateDataSourceConnectNetworks:getPrivateDataSourceConnectNetworks', __args__, opts=opts, typ=GetPrivateDataSourceConnectNetworksResult)
    return __ret__.apply(lambda __response__: GetPrivateDataSourceConnectNetworksResult(
        id=pulumi.get(__response__, 'id'),
        name_filter=pulumi.get(__response__, 'name_filter'),
        private_data_source_connect_networks=pulumi.get(__response__, 'private_data_source_connect_networks'),
        region_filter=pulumi.get(__response__, 'region_filter')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetSyntheticMonitoringProbesResult',
    'AwaitableGetSyntheticMonitoringProbesResult',
    'get_synthetic_monitoring_probes',
    'get_synthetic_monitoring_probes_output',
]

warnings.warn("""grafana.index/getsyntheticmonitoringprobes.getSyntheticMonitoringProbes has been deprecated in favor of grafana.syntheticmonitoring/getprobes.getProbes""", DeprecationWarning)

@pulumi.output_type
class GetSyntheticMonitoringProbesResult:
    """
    A collection of values returned by getSyntheticMonitoringProbes.
    """
    def __init__(__self__, filter_deprecated=None, id=None, probes=None):
        if filter_deprecated and not isinstance(filter_deprecated, bool):
            raise TypeError("Expected argument 'filter_deprecated' to be a bool")
        pulumi.set(__self__, "filter_deprecated", filter_deprecated)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if probes and not isinstance(probes, dict):
            raise TypeError("Expected argument 'probes' to be a dict")
        pulumi.set(__self__, "probes", probes)

    @property
    @pulumi.getter(name="filterDeprecated")
    def filter_deprecated(self) -> Optional[bool]:
        """
        If true, only probes that are not deprecated will be returned. Defaults to `true`.
        """
        return pulumi.get(self, "filter_deprecated")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def probes(self) -> Mapping[str, int]:
        """
        Map of probes with their names as keys and IDs as values.
        """
        return pulumi.get(self, "probes")


class AwaitableGetSyntheticMonitoringProbesResult(GetSyntheticMonitoringProbesResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetSyntheticMonitoringProbesResult(
            filter_deprecated=self.filter_deprecated,
            id=self.id,
            probes=self.probes)


def get_synthetic_monitoring_probes(filter_deprecated: Optional[bool] = None,
                                    opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetSyntheticMonitoringProbesResult:
    """
    Data source for retrieving all probes.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_grafana as grafana

    main = grafana.syntheticMonitoring.get_probes()
    ```


    :param bool filter_deprecated: If true, only probes that are not deprecated will be returned. Defaults to `true`.
    """
    pulumi.log.warn("""get_synthetic_monitoring_probes is deprecated: grafana.index/getsyntheticmonitoringprobes.getSyntheticMonitoringProbes has been deprecated in favor of grafana.syntheticmonitoring/getprobes.getProbes""")
    __args__ = dict()
    __args__['filterDeprecated'] = filter_deprecated
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('grafana:index/getSyntheticMonitoringProbes:getSyntheticMonitoringProbes', __args__, opts=opts, typ=GetSyntheticMonitoringProbesResult).value

    return AwaitableGetSyntheticMonitoringProbesResult(
        filter_deprecated=pulumi.get(__ret__, 'filter_deprecated'),
        id=pulumi.get(__ret__, 'id'),
        probes=pulumi.get(__ret__, 'probes'))
def get_synthetic_monitoring_probes_output(filter_deprecated: Optional[pulumi.Input[Optional[bool]]] = None,
                                           opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetSyntheticMonitoringProbesResult]:
    """
    Data source for retrieving all probes.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_grafana as grafana

    main = grafana.syntheticMonitoring.get_probes()
    ```


    :param bool filter_deprecated: If true, only probes that are not deprecated will be returned. Defaults to `true`.
    """
    pulumi.log.warn("""get_synthetic_monitoring_probes is deprecated: grafana.index/getsyntheticmonitoringprobes.getSyntheticMonitoringProbes has been deprecated in favor of grafana.syntheticmonitoring/getprobes.getProbes""")
    __args__ = dict()
    __args__['filterDeprecated'] = filter_deprecated
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('grafana:index/getSyntheticMonitoringProbes:getSyntheticMonitoringProbes', __args__, opts=opts, typ=GetSyntheticMonitoringProbesResult)
    return __ret__.apply(lambda __response__: GetSyntheticMonitoringProbesResult(
        filter_deprecated=pulumi.get(__response__, 'filter_deprecated'),
        id=pulumi.get(__response__, 'id'),
        probes=pulumi.get(__response__, 'probes')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetOncallScheduleResult',
    'AwaitableGetOncallScheduleResult',
    'get_oncall_schedule',
    'get_oncall_schedule_output',
]

warnings.warn("""grafana.index/getoncallschedule.getOncallSchedule has been deprecated in favor of grafana.oncall/getschedule.getSchedule""", DeprecationWarning)

@pulumi.output_type
class GetOncallScheduleResult:
    """
    A collection of values returned by getOncallSchedule.
    """
    def __init__(__self__, id=None, name=None, type=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if type and not isinstance(type, str):
            raise TypeError("Expected argument 'type' to be a str")
        pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        The schedule name.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def type(self) -> str:
        """
        The schedule type.
        """
        return pulumi.get(self, "type")


class AwaitableGetOncallScheduleResult(GetOncallScheduleResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetOncallScheduleResult(
            id=self.id,
            name=self.name,
            type=self.type)


def get_oncall_schedule(name: Optional[str] = None,
                        opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetOncallScheduleResult:
    """
    * [Official documentation](https://grafana.com/docs/oncall/latest/manage/on-call-schedules/)
    * [HTTP API](https://grafana.com/docs/oncall/latest/oncall-api-reference/schedules/)

    ## Example Usage

    ```python
    import pulumi
    import pulumi_grafana as grafana

    schedule = grafana.onCall.get_schedule(name="example_schedule")
    ```


    :param str name: The schedule name.
    """
    pulumi.log.warn("""get_oncall_schedule is deprecated: grafana.index/getoncallschedule.getOncallSchedule has been deprecated in favor of grafana.oncall/getschedule.getSchedule""")
    __args__ = dict()
    __args__['name'] = name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('grafana:index/getOncallSchedule:getOncallSchedule', __args__, opts=opts, typ=GetOncallScheduleResult).value

    return AwaitableGetOncallScheduleResult(
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'),
        type=pulumi.get(__ret__, 'type'))
def get_oncall_schedule_output(name: Optional[pulumi.Input[str]] = None,
                               opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetOncallScheduleResult]:
    """
    * [Official documentation](https://grafana.com/docs/oncall/latest/manage/on-call-schedules/)
    * [HTTP API](https://grafana.com/docs/oncall/latest/oncall-api-reference/schedules/)

    ## Example Usage

    ```python
    import pulumi
    import pulumi_grafana as grafana

    schedule = grafana.onCall.get_schedule(name="example_schedule")
    ```


    :param str name: The schedule name.
    """
    pulumi.log.warn("""get_oncall_schedule is deprecated: grafana.index/getoncallschedule.getOncallSchedule has been deprecated in favor of grafana.oncall/getschedule.getSchedule""")
    __args__ = dict()
    __args__['name'] = name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('grafana:index/getOncallSchedule:getOncallSchedule', __args__, opts=opts, typ=GetOncallScheduleResult)
    return __ret__.apply(lambda __response__: GetOncallScheduleResult(
        id=pulumi.get(__response__, 'id'),
        name=pulumi.get(__response__, 'name'),
        type=pulumi.get(__response__, 'type')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'DataSourcePermissionPermission',
    'ReportDashboard',
    'ReportDashboardTimeRange',
    'ReportSchedule',
    'RolePermission',
    'GetRolePermissionResult',
]

@pulumi.output_type
class DataSourcePermissionPermission(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "builtInRole":
            suggest = "built_in_role"
        elif key == "teamId":
            suggest = "team_id"
        elif key == "userId":
            suggest = "user_id"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in DataSourcePermissionPermission. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        DataSourcePermissionPermission.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        DataSourcePermissionPermission.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 permission: str,
                 built_in_role: Optional[str] = None,
                 team_id: Optional[str] = None,
                 user_id: Optional[str] = None):
        """
        :param str permission: Permission to associate with item. Options: `Query`, `Edit` or `Admin` (`Admin` can only be used with Grafana v10.3.0+).
        :param str built_in_role: Name of the basic role to manage permissions for. Options: `Viewer`, `Editor` or `Admin`.
        :param str team_id: ID of the team to manage permissions for. Defaults to `0`.
        :param str user_id: ID of the user or service account to manage permissions for. Defaults to `0`.
        """
        pulumi.set(__self__, "permission", permission)
        if built_in_role is not None:
            pulumi.set(__self__, "built_in_role", built_in_role)
        if team_id is not None:
            pulumi.set(__self__, "team_id", team_id)
        if user_id is not None:
            pulumi.set(__self__, "user_id", user_id)

    @property
    @pulumi.getter
    def permission(self) -> str:
        """
        Permission to associate with item. Options: `Query`, `Edit` or `Admin` (`Admin` can only be used with Grafana v10.3.0+).
        """
        return pulumi.get(self, "permission")

    @property
    @pulumi.getter(name="builtInRole")
    def built_in_role(self) -> Optional[str]:
        """
        Name of the basic role to manage permissions for. Options: `Viewer`, `Editor` or `Admin`.
        """
        return pulumi.get(self, "built_in_role")

    @property
    @pulumi.getter(name="teamId")
    def team_id(self) -> Optional[str]:
        """
        ID of the team to manage permissions for. Defaults to `0`.
        """
        return pulumi.get(self, "team_id")

    @property
    @pulumi.getter(name="userId")
    def user_id(self) -> Optional[str]:
        """
        ID of the user or service account to manage permissions for. Defaults to `0`.
        """
        return pulumi.get(self, "user_id")


@pulumi.output_type
class ReportDashboard(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "reportVariables":
            suggest = "report_variables"
        elif key == "timeRange":
            suggest = "time_range"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ReportDashboard. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ReportDashboard.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ReportDashboard.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 uid: str,
                 report_variables: Optional[Mapping[str, str]] = None,
                 time_range: Optional['outputs.ReportDashboardTimeRange'] = None):
        """
        :param str uid: Dashboard uid.
        :param Mapping[str, str] report_variables: Add report variables to the dashboard. Values should be separated by commas.
        :param 'ReportDashboardTimeRangeArgs' time_range: Time range of the report.
        """
        pulumi.set(__self__, "uid", uid)
        if report_variables is not None:
            pulumi.set(__self__, "report_variables", report_variables)
        if time_range is not None:
            pulumi.set(__self__, "time_range", time_range)

    @property
    @pulumi.getter
    def uid(self) -> str:
        """
        Dashboard uid.
        """
        return pulumi.get(self, "uid")

    @property
    @pulumi.getter(name="reportVariables")
    def report_variables(self) -> Optional[Mapping[str, str]]:
        """
        Add report variables to the dashboard. Values should be separated by commas.
        """
        return pulumi.get(self, "report_variables")

    @property
    @pulumi.getter(name="timeRange")
    def time_range(self) -> Optional['outputs.ReportDashboardTimeRange']:
        """
        Time range of the report.
        """
        return pulumi.get(self, "time_range")


@pulumi.output_type
class ReportDashboardTimeRange(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "from":
            suggest = "from_"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ReportDashboardTimeRange. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ReportDashboardTimeRange.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ReportDashboardTimeRange.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 from_: Optional[str] = None,
                 to: Optional[str] = None):
        """
        :param str from_: Start of the time range.
        :param str to: End of the time range.
        """
        if from_ is not None:
            pulumi.set(__self__, "from_", from_)
        if to is not None:
            pulumi.set(__self__, "to", to)

    @property
    @pulumi.getter(name="from")
    def from_(self) -> Optional[str]:
        """
        Start of the time range.
        """
        return pulumi.get(self, "from_")

    @property
    @pulumi.getter
    def to(self) -> Optional[str]:
        """
        End of the time range.
        """
        return pulumi.get(self, "to")


@pulumi.output_type
class ReportSchedule(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "customInterval":
            suggest = "custom_interval"
        elif key == "endTime":
            suggest = "end_time"
        elif key == "lastDayOfMonth":
            suggest = "last_day_of_month"
        elif key == "startTime":
            suggest = "start_time"
        elif key == "workdaysOnly":
            suggest = "workdays_only"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ReportSchedule. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ReportSchedule.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ReportSchedule.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 frequency: str,
                 custom_interval: Optional[str] = None,
                 end_time: Optional[str] = None,
                 last_day_of_month: Optional[bool] = None,
                 start_time: Optional[str] = None,
                 timezone: Optional[str] = None,
                 workdays_only: Optional[bool] = None):
        """
        :param str frequency: Frequency of the report. Allowed values: `never`, `once`, `hourly`, `daily`, `weekly`, `monthly`, `custom`.
        :param str custom_interval: Custom interval of the report.
               **Note:** This field is only available when frequency is set to `custom`.
        :param str end_time: End time of the report. If empty, the report will be sent indefinitely (according to frequency). Note that times will be saved as UTC in Grafana. Use 2006-01-02T15:04:05 format if you want to set a custom timezone
        :param bool last_day_of_month: Send the report on the last day of the month Defaults to `false`.
        :param str start_time: Start time of the report. If empty, the start date will be set to the creation time. Note that times will be saved as UTC in Grafana. Use 2006-01-02T15:04:05 format if you want to set a custom timezone
        :param str timezone: Set the report time zone. Defaults to `GMT`.
        :param bool workdays_only: Whether to send the report only on work days. Defaults to `false`.
        """
        pulumi.set(__self__, "frequency", frequency)
        if custom_interval is not None:
            pulumi.set(__self__, "custom_interval", custom_interval)
        if end_time is not None:
            pulumi.set(__self__, "end_time", end_time)
        if last_day_of_month is not None:
            pulumi.set(__self__, "last_day_of_month", last_day_of_month)
        if start_time is not None:
            pulumi.set(__self__, "start_time", start_time)
        if timezone is not None:
            pulumi.set(__self__, "timezone", timezone)
        if workdays_only is not None:
            pulumi.set(__self__, "workdays_only", workdays_only)

    @property
    @pulumi.getter
    def frequency(self) -> str:
        """
        Frequency of the report. Allowed values: `never`, `once`, `hourly`, `daily`, `weekly`, `monthly`, `custom`.
        """
        return pulumi.get(self, "frequency")

    @property
    @pulumi.getter(name="customInterval")
    def custom_interval(self) -> Optional[str]:
        """
        Custom interval of the report.
        **Note:** This field is only available when frequency is set to `custom`.
        """
        return pulumi.get(self, "custom_interval")

    @property
    @pulumi.getter(name="endTime")
    def end_time(self) -> Optional[str]:
        """
        End time of the report. If empty, the report will be sent indefinitely (according to frequency). Note that times will be saved as UTC in Grafana. Use 2006-01-02T15:04:05 format if you want to set a custom timezone
        """
        return pulumi.get(self, "end_time")

    @property
    @pulumi.getter(name="lastDayOfMonth")
    def last_day_of_month(self) -> Optional[bool]:
        """
        Send the report on the last day of the month Defaults to `false`.
        """
        return pulumi.get(self, "last_day_of_month")

    @property
    @pulumi.getter(name="startTime")
    def start_time(self) -> Optional[str]:
        """
        Start time of the report. If empty, the start date will be set to the creation time. Note that times will be saved as UTC in Grafana. Use 2006-01-02T15:04:05 format if you want to set a custom timezone
        """
        return pulumi.get(self, "start_time")

    @property
    @pulumi.getter
    def timezone(self) -> Optional[str]:
        """
        Set the report time zone. Defaults to `GMT`.
        """
        return pulumi.get(self, "timezone")

    @property
    @pulumi.getter(name="workdaysOnly")
    def workdays_only(self) -> Optional[bool]:
        """
        Whether to send the report only on work days. Defaults to `false`.
        """
        return pulumi.get(self, "workdays_only")


@pulumi.output_type
class RolePermission(dict):
    def __init__(__self__, *,
                 action: str,
                 scope: Optional[str] = None):
        """
        :param str action: Specific action users granted with the role will be allowed to perform (for example: `users:read`)
        :param str scope: Scope to restrict the action to a set of resources (for example: `users:*` or `roles:customrole1`) Defaults to ``.
        """
        pulumi.set(__self__, "action", action)
        if scope is not None:
            pulumi.set(__self__, "scope", scope)

    @property
    @pulumi.getter
    def action(self) -> str:
        """
        Specific action users granted with the role will be allowed to perform (for example: `users:read`)
        """
        return pulumi.get(self, "action")

    @property
    @pulumi.getter
    def scope(self) -> Optional[str]:
        """
        Scope to restrict the action to a set of resources (for example: `users:*` or `roles:customrole1`) Defaults to ``.
        """
        return pulumi.get(self, "scope")


@pulumi.output_type
class GetRolePermissionResult(dict):
    def __init__(__self__, *,
                 action: str,
                 scope: Optional[str] = None):
        """
        :param str action: Specific action users granted with the role will be allowed to perform (for example: `users:read`)
        :param str scope: Scope to restrict the action to a set of resources (for example: `users:*` or `roles:customrole1`)
        """
        pulumi.set(__self__, "action", action)
        if scope is not None:
            pulumi.set(__self__, "scope", scope)

    @property
    @pulumi.getter
    def action(self) -> str:
        """
        Specific action users granted with the role will be allowed to perform (for example: `users:read`)
        """
        return pulumi.get(self, "action")

    @property
    @pulumi.getter
    def scope(self) -> Optional[str]:
        """
        Scope to restrict the action to a set of resources (for example: `users:*` or `roles:customrole1`)
        """
        return pulumi.get(self, "scope")





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetDashboardResult',
    'AwaitableGetDashboardResult',
    'get_dashboard',
    'get_dashboard_output',
]

@pulumi.output_type
class GetDashboardResult:
    """
    A collection of values returned by getDashboard.
    """
    def __init__(__self__, config_json=None, dashboard_id=None, folder_uid=None, id=None, is_starred=None, org_id=None, slug=None, title=None, uid=None, url=None, version=None):
        if config_json and not isinstance(config_json, str):
            raise TypeError("Expected argument 'config_json' to be a str")
        pulumi.set(__self__, "config_json", config_json)
        if dashboard_id and not isinstance(dashboard_id, int):
            raise TypeError("Expected argument 'dashboard_id' to be a int")
        pulumi.set(__self__, "dashboard_id", dashboard_id)
        if folder_uid and not isinstance(folder_uid, str):
            raise TypeError("Expected argument 'folder_uid' to be a str")
        pulumi.set(__self__, "folder_uid", folder_uid)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if is_starred and not isinstance(is_starred, bool):
            raise TypeError("Expected argument 'is_starred' to be a bool")
        pulumi.set(__self__, "is_starred", is_starred)
        if org_id and not isinstance(org_id, str):
            raise TypeError("Expected argument 'org_id' to be a str")
        pulumi.set(__self__, "org_id", org_id)
        if slug and not isinstance(slug, str):
            raise TypeError("Expected argument 'slug' to be a str")
        pulumi.set(__self__, "slug", slug)
        if title and not isinstance(title, str):
            raise TypeError("Expected argument 'title' to be a str")
        pulumi.set(__self__, "title", title)
        if uid and not isinstance(uid, str):
            raise TypeError("Expected argument 'uid' to be a str")
        pulumi.set(__self__, "uid", uid)
        if url and not isinstance(url, str):
            raise TypeError("Expected argument 'url' to be a str")
        pulumi.set(__self__, "url", url)
        if version and not isinstance(version, int):
            raise TypeError("Expected argument 'version' to be a int")
        pulumi.set(__self__, "version", version)

    @property
    @pulumi.getter(name="configJson")
    def config_json(self) -> str:
        """
        The complete dashboard model JSON.
        """
        return pulumi.get(self, "config_json")

    @property
    @pulumi.getter(name="dashboardId")
    def dashboard_id(self) -> Optional[int]:
        """
        The numerical ID of the Grafana dashboard. Specify either this or `uid`. Defaults to `-1`.
        """
        return pulumi.get(self, "dashboard_id")

    @property
    @pulumi.getter(name="folderUid")
    def folder_uid(self) -> str:
        """
        The UID of the folder where the Grafana dashboard is found.
        """
        return pulumi.get(self, "folder_uid")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="isStarred")
    def is_starred(self) -> bool:
        """
        Whether or not the Grafana dashboard is starred. Starred Dashboards will show up on your own Home Dashboard by default, and are a convenient way to mark Dashboards that you’re interested in.
        """
        return pulumi.get(self, "is_starred")

    @property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[str]:
        """
        The Organization ID. If not set, the Org ID defined in the provider block will be used.
        """
        return pulumi.get(self, "org_id")

    @property
    @pulumi.getter
    def slug(self) -> str:
        """
        URL slug of the dashboard (deprecated).
        """
        return pulumi.get(self, "slug")

    @property
    @pulumi.getter
    def title(self) -> str:
        """
        The title of the Grafana dashboard.
        """
        return pulumi.get(self, "title")

    @property
    @pulumi.getter
    def uid(self) -> Optional[str]:
        """
        The uid of the Grafana dashboard. Specify either this or `dashboard_id`. Defaults to ``.
        """
        return pulumi.get(self, "uid")

    @property
    @pulumi.getter
    def url(self) -> str:
        """
        The full URL of the dashboard.
        """
        return pulumi.get(self, "url")

    @property
    @pulumi.getter
    def version(self) -> int:
        """
        The numerical version of the Grafana dashboard.
        """
        return pulumi.get(self, "version")


class AwaitableGetDashboardResult(GetDashboardResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetDashboardResult(
            config_json=self.config_json,
            dashboard_id=self.dashboard_id,
            folder_uid=self.folder_uid,
            id=self.id,
            is_starred=self.is_starred,
            org_id=self.org_id,
            slug=self.slug,
            title=self.title,
            uid=self.uid,
            url=self.url,
            version=self.version)


def get_dashboard(dashboard_id: Optional[int] = None,
                  org_id: Optional[str] = None,
                  uid: Optional[str] = None,
                  opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetDashboardResult:
    """
    * [Official documentation](https://grafana.com/docs/grafana/latest/dashboards/)
    * [Folder/Dashboard Search HTTP API](https://grafana.com/docs/grafana/latest/developers/http_api/folder_dashboard_search/)
    * [Dashboard HTTP API](https://grafana.com/docs/grafana/latest/developers/http_api/dashboard/)

    ## Example Usage

    ```python
    import pulumi
    import json
    import pulumi_grafana as grafana
    import pulumiverse_grafana as grafana

    test = grafana.oss.Dashboard("test", config_json=json.dumps({
        "id": 12345,
        "uid": "test-ds-dashboard-uid",
        "title": "Production Overview",
        "tags": ["templated"],
        "timezone": "browser",
        "schemaVersion": 16,
        "version": 0,
        "refresh": "25s",
    }))
    from_uid = grafana.oss.get_dashboard(uid="test-ds-dashboard-uid")
    ```


    :param int dashboard_id: The numerical ID of the Grafana dashboard. Specify either this or `uid`. Defaults to `-1`.
    :param str org_id: The Organization ID. If not set, the Org ID defined in the provider block will be used.
    :param str uid: The uid of the Grafana dashboard. Specify either this or `dashboard_id`. Defaults to ``.
    """
    __args__ = dict()
    __args__['dashboardId'] = dashboard_id
    __args__['orgId'] = org_id
    __args__['uid'] = uid
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('grafana:oss/getDashboard:getDashboard', __args__, opts=opts, typ=GetDashboardResult).value

    return AwaitableGetDashboardResult(
        config_json=pulumi.get(__ret__, 'config_json'),
        dashboard_id=pulumi.get(__ret__, 'dashboard_id'),
        folder_uid=pulumi.get(__ret__, 'folder_uid'),
        id=pulumi.get(__ret__, 'id'),
        is_starred=pulumi.get(__ret__, 'is_starred'),
        org_id=pulumi.get(__ret__, 'org_id'),
        slug=pulumi.get(__ret__, 'slug'),
        title=pulumi.get(__ret__, 'title'),
        uid=pulumi.get(__ret__, 'uid'),
        url=pulumi.get(__ret__, 'url'),
        version=pulumi.get(__ret__, 'version'))
def get_dashboard_output(dashboard_id: Optional[pulumi.Input[Optional[int]]] = None,
                         org_id: Optional[pulumi.Input[Optional[str]]] = None,
                         uid: Optional[pulumi.Input[Optional[str]]] = None,
                         opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetDashboardResult]:
    """
    * [Official documentation](https://grafana.com/docs/grafana/latest/dashboards/)
    * [Folder/Dashboard Search HTTP API](https://grafana.com/docs/grafana/latest/developers/http_api/folder_dashboard_search/)
    * [Dashboard HTTP API](https://grafana.com/docs/grafana/latest/developers/http_api/dashboard/)

    ## Example Usage

    ```python
    import pulumi
    import json
    import pulumi_grafana as grafana
    import pulumiverse_grafana as grafana

    test = grafana.oss.Dashboard("test", config_json=json.dumps({
        "id": 12345,
        "uid": "test-ds-dashboard-uid",
        "title": "Production Overview",
        "tags": ["templated"],
        "timezone": "browser",
        "schemaVersion": 16,
        "version": 0,
        "refresh": "25s",
    }))
    from_uid = grafana.oss.get_dashboard(uid="test-ds-dashboard-uid")
    ```


    :param int dashboard_id: The numerical ID of the Grafana dashboard. Specify either this or `uid`. Defaults to `-1`.
    :param str org_id: The Organization ID. If not set, the Org ID defined in the provider block will be used.
    :param str uid: The uid of the Grafana dashboard. Specify either this or `dashboard_id`. Defaults to ``.
    """
    __args__ = dict()
    __args__['dashboardId'] = dashboard_id
    __args__['orgId'] = org_id
    __args__['uid'] = uid
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('grafana:oss/getDashboard:getDashboard', __args__, opts=opts, typ=GetDashboardResult)
    return __ret__.apply(lambda __response__: GetDashboardResult(
        config_json=pulumi.get(__response__, 'config_json'),
        dashboard_id=pulumi.get(__response__, 'dashboard_id'),
        folder_uid=pulumi.get(__response__, 'folder_uid'),
        id=pulumi.get(__response__, 'id'),
        is_starred=pulumi.get(__response__, 'is_starred'),
        org_id=pulumi.get(__response__, 'org_id'),
        slug=pulumi.get(__response__, 'slug'),
        title=pulumi.get(__response__, 'title'),
        uid=pulumi.get(__response__, 'uid'),
        url=pulumi.get(__response__, 'url'),
        version=pulumi.get(__response__, 'version')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['CloudPluginInstallationArgs', 'CloudPluginInstallation']

@pulumi.input_type
class CloudPluginInstallationArgs:
    def __init__(__self__, *,
                 slug: pulumi.Input[str],
                 stack_slug: pulumi.Input[str],
                 version: pulumi.Input[str]):
        """
        The set of arguments for constructing a CloudPluginInstallation resource.
        :param pulumi.Input[str] slug: Slug of the plugin to be installed.
        :param pulumi.Input[str] stack_slug: The stack id to which the plugin should be installed.
        :param pulumi.Input[str] version: Version of the plugin to be installed.
        """
        pulumi.set(__self__, "slug", slug)
        pulumi.set(__self__, "stack_slug", stack_slug)
        pulumi.set(__self__, "version", version)

    @property
    @pulumi.getter
    def slug(self) -> pulumi.Input[str]:
        """
        Slug of the plugin to be installed.
        """
        return pulumi.get(self, "slug")

    @slug.setter
    def slug(self, value: pulumi.Input[str]):
        pulumi.set(self, "slug", value)

    @property
    @pulumi.getter(name="stackSlug")
    def stack_slug(self) -> pulumi.Input[str]:
        """
        The stack id to which the plugin should be installed.
        """
        return pulumi.get(self, "stack_slug")

    @stack_slug.setter
    def stack_slug(self, value: pulumi.Input[str]):
        pulumi.set(self, "stack_slug", value)

    @property
    @pulumi.getter
    def version(self) -> pulumi.Input[str]:
        """
        Version of the plugin to be installed.
        """
        return pulumi.get(self, "version")

    @version.setter
    def version(self, value: pulumi.Input[str]):
        pulumi.set(self, "version", value)


@pulumi.input_type
class _CloudPluginInstallationState:
    def __init__(__self__, *,
                 slug: Optional[pulumi.Input[str]] = None,
                 stack_slug: Optional[pulumi.Input[str]] = None,
                 version: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering CloudPluginInstallation resources.
        :param pulumi.Input[str] slug: Slug of the plugin to be installed.
        :param pulumi.Input[str] stack_slug: The stack id to which the plugin should be installed.
        :param pulumi.Input[str] version: Version of the plugin to be installed.
        """
        if slug is not None:
            pulumi.set(__self__, "slug", slug)
        if stack_slug is not None:
            pulumi.set(__self__, "stack_slug", stack_slug)
        if version is not None:
            pulumi.set(__self__, "version", version)

    @property
    @pulumi.getter
    def slug(self) -> Optional[pulumi.Input[str]]:
        """
        Slug of the plugin to be installed.
        """
        return pulumi.get(self, "slug")

    @slug.setter
    def slug(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "slug", value)

    @property
    @pulumi.getter(name="stackSlug")
    def stack_slug(self) -> Optional[pulumi.Input[str]]:
        """
        The stack id to which the plugin should be installed.
        """
        return pulumi.get(self, "stack_slug")

    @stack_slug.setter
    def stack_slug(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "stack_slug", value)

    @property
    @pulumi.getter
    def version(self) -> Optional[pulumi.Input[str]]:
        """
        Version of the plugin to be installed.
        """
        return pulumi.get(self, "version")

    @version.setter
    def version(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "version", value)


warnings.warn("""grafana.index/cloudplugininstallation.CloudPluginInstallation has been deprecated in favor of grafana.cloud/plugininstallation.PluginInstallation""", DeprecationWarning)


class CloudPluginInstallation(pulumi.CustomResource):
    warnings.warn("""grafana.index/cloudplugininstallation.CloudPluginInstallation has been deprecated in favor of grafana.cloud/plugininstallation.PluginInstallation""", DeprecationWarning)

    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 slug: Optional[pulumi.Input[str]] = None,
                 stack_slug: Optional[pulumi.Input[str]] = None,
                 version: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Manages Grafana Cloud Plugin Installations.

        * [Plugin Catalog](https://grafana.com/grafana/plugins/)

        Required access policy scopes:

        * stack-plugins:read
        * stack-plugins:write
        * stack-plugins:delete

        ## Example Usage

        ```python
        import pulumi
        import pulumiverse_grafana as grafana

        test = grafana.cloud.PluginInstallation("test",
            stack_slug="stackname",
            slug="some-plugin",
            version="1.2.3")
        ```

        ## Import

        ```sh
        $ pulumi import grafana:index/cloudPluginInstallation:CloudPluginInstallation name "{{ stackSlug }}:{{ pluginSlug }}"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] slug: Slug of the plugin to be installed.
        :param pulumi.Input[str] stack_slug: The stack id to which the plugin should be installed.
        :param pulumi.Input[str] version: Version of the plugin to be installed.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: CloudPluginInstallationArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages Grafana Cloud Plugin Installations.

        * [Plugin Catalog](https://grafana.com/grafana/plugins/)

        Required access policy scopes:

        * stack-plugins:read
        * stack-plugins:write
        * stack-plugins:delete

        ## Example Usage

        ```python
        import pulumi
        import pulumiverse_grafana as grafana

        test = grafana.cloud.PluginInstallation("test",
            stack_slug="stackname",
            slug="some-plugin",
            version="1.2.3")
        ```

        ## Import

        ```sh
        $ pulumi import grafana:index/cloudPluginInstallation:CloudPluginInstallation name "{{ stackSlug }}:{{ pluginSlug }}"
        ```

        :param str resource_name: The name of the resource.
        :param CloudPluginInstallationArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(CloudPluginInstallationArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 slug: Optional[pulumi.Input[str]] = None,
                 stack_slug: Optional[pulumi.Input[str]] = None,
                 version: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        pulumi.log.warn("""CloudPluginInstallation is deprecated: grafana.index/cloudplugininstallation.CloudPluginInstallation has been deprecated in favor of grafana.cloud/plugininstallation.PluginInstallation""")
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = CloudPluginInstallationArgs.__new__(CloudPluginInstallationArgs)

            if slug is None and not opts.urn:
                raise TypeError("Missing required property 'slug'")
            __props__.__dict__["slug"] = slug
            if stack_slug is None and not opts.urn:
                raise TypeError("Missing required property 'stack_slug'")
            __props__.__dict__["stack_slug"] = stack_slug
            if version is None and not opts.urn:
                raise TypeError("Missing required property 'version'")
            __props__.__dict__["version"] = version
        super(CloudPluginInstallation, __self__).__init__(
            'grafana:index/cloudPluginInstallation:CloudPluginInstallation',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            slug: Optional[pulumi.Input[str]] = None,
            stack_slug: Optional[pulumi.Input[str]] = None,
            version: Optional[pulumi.Input[str]] = None) -> 'CloudPluginInstallation':
        """
        Get an existing CloudPluginInstallation resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] slug: Slug of the plugin to be installed.
        :param pulumi.Input[str] stack_slug: The stack id to which the plugin should be installed.
        :param pulumi.Input[str] version: Version of the plugin to be installed.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _CloudPluginInstallationState.__new__(_CloudPluginInstallationState)

        __props__.__dict__["slug"] = slug
        __props__.__dict__["stack_slug"] = stack_slug
        __props__.__dict__["version"] = version
        return CloudPluginInstallation(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def slug(self) -> pulumi.Output[str]:
        """
        Slug of the plugin to be installed.
        """
        return pulumi.get(self, "slug")

    @property
    @pulumi.getter(name="stackSlug")
    def stack_slug(self) -> pulumi.Output[str]:
        """
        The stack id to which the plugin should be installed.
        """
        return pulumi.get(self, "stack_slug")

    @property
    @pulumi.getter
    def version(self) -> pulumi.Output[str]:
        """
        Version of the plugin to be installed.
        """
        return pulumi.get(self, "version")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['OncallEscalationArgs', 'OncallEscalation']

@pulumi.input_type
class OncallEscalationArgs:
    def __init__(__self__, *,
                 escalation_chain_id: pulumi.Input[str],
                 position: pulumi.Input[int],
                 type: pulumi.Input[str],
                 action_to_trigger: Optional[pulumi.Input[str]] = None,
                 duration: Optional[pulumi.Input[int]] = None,
                 group_to_notify: Optional[pulumi.Input[str]] = None,
                 important: Optional[pulumi.Input[bool]] = None,
                 notify_if_time_from: Optional[pulumi.Input[str]] = None,
                 notify_if_time_to: Optional[pulumi.Input[str]] = None,
                 notify_on_call_from_schedule: Optional[pulumi.Input[str]] = None,
                 notify_to_team_members: Optional[pulumi.Input[str]] = None,
                 persons_to_notifies: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 persons_to_notify_next_each_times: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 severity: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a OncallEscalation resource.
        :param pulumi.Input[str] escalation_chain_id: The ID of the escalation chain.
        :param pulumi.Input[int] position: The position of the escalation step (starts from 0).
        :param pulumi.Input[str] type: The type of escalation policy. Can be wait, notify*persons, notify*person*next*each*time, notify*on*call*from*schedule, trigger*webhook, notify*user*group, resolve, notify*whole*channel, notify*if*time*from*to, repeat*escalation, notify*team*members, declare*incident
        :param pulumi.Input[str] action_to_trigger: The ID of an Action for trigger_webhook type step.
        :param pulumi.Input[int] duration: The duration of delay for wait type step. (60-86400) seconds
        :param pulumi.Input[str] group_to_notify: The ID of a User Group for notify*user*group type step.
        :param pulumi.Input[bool] important: Will activate "important" personal notification rules. Actual for steps: notify*persons, notify*person*next*each*time, notify*on*call*from*schedule, notify*user*group and notify*team_members
        :param pulumi.Input[str] notify_if_time_from: The beginning of the time interval for notify*if*time*from*to type step in UTC (for example 08:00:00Z).
        :param pulumi.Input[str] notify_if_time_to: The end of the time interval for notify*if*time*from*to type step in UTC (for example 18:00:00Z).
        :param pulumi.Input[str] notify_on_call_from_schedule: ID of a Schedule for notify*on*call*from*schedule type step.
        :param pulumi.Input[str] notify_to_team_members: The ID of a Team for a notify*team*members type step.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] persons_to_notifies: The list of ID's of users for notify_persons type step.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] persons_to_notify_next_each_times: The list of ID's of users for notify*person*next*each*time type step.
        :param pulumi.Input[str] severity: The severity of the incident for declare_incident type step.
        """
        pulumi.set(__self__, "escalation_chain_id", escalation_chain_id)
        pulumi.set(__self__, "position", position)
        pulumi.set(__self__, "type", type)
        if action_to_trigger is not None:
            pulumi.set(__self__, "action_to_trigger", action_to_trigger)
        if duration is not None:
            pulumi.set(__self__, "duration", duration)
        if group_to_notify is not None:
            pulumi.set(__self__, "group_to_notify", group_to_notify)
        if important is not None:
            pulumi.set(__self__, "important", important)
        if notify_if_time_from is not None:
            pulumi.set(__self__, "notify_if_time_from", notify_if_time_from)
        if notify_if_time_to is not None:
            pulumi.set(__self__, "notify_if_time_to", notify_if_time_to)
        if notify_on_call_from_schedule is not None:
            pulumi.set(__self__, "notify_on_call_from_schedule", notify_on_call_from_schedule)
        if notify_to_team_members is not None:
            pulumi.set(__self__, "notify_to_team_members", notify_to_team_members)
        if persons_to_notifies is not None:
            pulumi.set(__self__, "persons_to_notifies", persons_to_notifies)
        if persons_to_notify_next_each_times is not None:
            pulumi.set(__self__, "persons_to_notify_next_each_times", persons_to_notify_next_each_times)
        if severity is not None:
            pulumi.set(__self__, "severity", severity)

    @property
    @pulumi.getter(name="escalationChainId")
    def escalation_chain_id(self) -> pulumi.Input[str]:
        """
        The ID of the escalation chain.
        """
        return pulumi.get(self, "escalation_chain_id")

    @escalation_chain_id.setter
    def escalation_chain_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "escalation_chain_id", value)

    @property
    @pulumi.getter
    def position(self) -> pulumi.Input[int]:
        """
        The position of the escalation step (starts from 0).
        """
        return pulumi.get(self, "position")

    @position.setter
    def position(self, value: pulumi.Input[int]):
        pulumi.set(self, "position", value)

    @property
    @pulumi.getter
    def type(self) -> pulumi.Input[str]:
        """
        The type of escalation policy. Can be wait, notify*persons, notify*person*next*each*time, notify*on*call*from*schedule, trigger*webhook, notify*user*group, resolve, notify*whole*channel, notify*if*time*from*to, repeat*escalation, notify*team*members, declare*incident
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: pulumi.Input[str]):
        pulumi.set(self, "type", value)

    @property
    @pulumi.getter(name="actionToTrigger")
    def action_to_trigger(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of an Action for trigger_webhook type step.
        """
        return pulumi.get(self, "action_to_trigger")

    @action_to_trigger.setter
    def action_to_trigger(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "action_to_trigger", value)

    @property
    @pulumi.getter
    def duration(self) -> Optional[pulumi.Input[int]]:
        """
        The duration of delay for wait type step. (60-86400) seconds
        """
        return pulumi.get(self, "duration")

    @duration.setter
    def duration(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "duration", value)

    @property
    @pulumi.getter(name="groupToNotify")
    def group_to_notify(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of a User Group for notify*user*group type step.
        """
        return pulumi.get(self, "group_to_notify")

    @group_to_notify.setter
    def group_to_notify(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "group_to_notify", value)

    @property
    @pulumi.getter
    def important(self) -> Optional[pulumi.Input[bool]]:
        """
        Will activate "important" personal notification rules. Actual for steps: notify*persons, notify*person*next*each*time, notify*on*call*from*schedule, notify*user*group and notify*team_members
        """
        return pulumi.get(self, "important")

    @important.setter
    def important(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "important", value)

    @property
    @pulumi.getter(name="notifyIfTimeFrom")
    def notify_if_time_from(self) -> Optional[pulumi.Input[str]]:
        """
        The beginning of the time interval for notify*if*time*from*to type step in UTC (for example 08:00:00Z).
        """
        return pulumi.get(self, "notify_if_time_from")

    @notify_if_time_from.setter
    def notify_if_time_from(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "notify_if_time_from", value)

    @property
    @pulumi.getter(name="notifyIfTimeTo")
    def notify_if_time_to(self) -> Optional[pulumi.Input[str]]:
        """
        The end of the time interval for notify*if*time*from*to type step in UTC (for example 18:00:00Z).
        """
        return pulumi.get(self, "notify_if_time_to")

    @notify_if_time_to.setter
    def notify_if_time_to(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "notify_if_time_to", value)

    @property
    @pulumi.getter(name="notifyOnCallFromSchedule")
    def notify_on_call_from_schedule(self) -> Optional[pulumi.Input[str]]:
        """
        ID of a Schedule for notify*on*call*from*schedule type step.
        """
        return pulumi.get(self, "notify_on_call_from_schedule")

    @notify_on_call_from_schedule.setter
    def notify_on_call_from_schedule(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "notify_on_call_from_schedule", value)

    @property
    @pulumi.getter(name="notifyToTeamMembers")
    def notify_to_team_members(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of a Team for a notify*team*members type step.
        """
        return pulumi.get(self, "notify_to_team_members")

    @notify_to_team_members.setter
    def notify_to_team_members(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "notify_to_team_members", value)

    @property
    @pulumi.getter(name="personsToNotifies")
    def persons_to_notifies(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        The list of ID's of users for notify_persons type step.
        """
        return pulumi.get(self, "persons_to_notifies")

    @persons_to_notifies.setter
    def persons_to_notifies(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "persons_to_notifies", value)

    @property
    @pulumi.getter(name="personsToNotifyNextEachTimes")
    def persons_to_notify_next_each_times(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        The list of ID's of users for notify*person*next*each*time type step.
        """
        return pulumi.get(self, "persons_to_notify_next_each_times")

    @persons_to_notify_next_each_times.setter
    def persons_to_notify_next_each_times(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "persons_to_notify_next_each_times", value)

    @property
    @pulumi.getter
    def severity(self) -> Optional[pulumi.Input[str]]:
        """
        The severity of the incident for declare_incident type step.
        """
        return pulumi.get(self, "severity")

    @severity.setter
    def severity(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "severity", value)


@pulumi.input_type
class _OncallEscalationState:
    def __init__(__self__, *,
                 action_to_trigger: Optional[pulumi.Input[str]] = None,
                 duration: Optional[pulumi.Input[int]] = None,
                 escalation_chain_id: Optional[pulumi.Input[str]] = None,
                 group_to_notify: Optional[pulumi.Input[str]] = None,
                 important: Optional[pulumi.Input[bool]] = None,
                 notify_if_time_from: Optional[pulumi.Input[str]] = None,
                 notify_if_time_to: Optional[pulumi.Input[str]] = None,
                 notify_on_call_from_schedule: Optional[pulumi.Input[str]] = None,
                 notify_to_team_members: Optional[pulumi.Input[str]] = None,
                 persons_to_notifies: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 persons_to_notify_next_each_times: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 position: Optional[pulumi.Input[int]] = None,
                 severity: Optional[pulumi.Input[str]] = None,
                 type: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering OncallEscalation resources.
        :param pulumi.Input[str] action_to_trigger: The ID of an Action for trigger_webhook type step.
        :param pulumi.Input[int] duration: The duration of delay for wait type step. (60-86400) seconds
        :param pulumi.Input[str] escalation_chain_id: The ID of the escalation chain.
        :param pulumi.Input[str] group_to_notify: The ID of a User Group for notify*user*group type step.
        :param pulumi.Input[bool] important: Will activate "important" personal notification rules. Actual for steps: notify*persons, notify*person*next*each*time, notify*on*call*from*schedule, notify*user*group and notify*team_members
        :param pulumi.Input[str] notify_if_time_from: The beginning of the time interval for notify*if*time*from*to type step in UTC (for example 08:00:00Z).
        :param pulumi.Input[str] notify_if_time_to: The end of the time interval for notify*if*time*from*to type step in UTC (for example 18:00:00Z).
        :param pulumi.Input[str] notify_on_call_from_schedule: ID of a Schedule for notify*on*call*from*schedule type step.
        :param pulumi.Input[str] notify_to_team_members: The ID of a Team for a notify*team*members type step.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] persons_to_notifies: The list of ID's of users for notify_persons type step.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] persons_to_notify_next_each_times: The list of ID's of users for notify*person*next*each*time type step.
        :param pulumi.Input[int] position: The position of the escalation step (starts from 0).
        :param pulumi.Input[str] severity: The severity of the incident for declare_incident type step.
        :param pulumi.Input[str] type: The type of escalation policy. Can be wait, notify*persons, notify*person*next*each*time, notify*on*call*from*schedule, trigger*webhook, notify*user*group, resolve, notify*whole*channel, notify*if*time*from*to, repeat*escalation, notify*team*members, declare*incident
        """
        if action_to_trigger is not None:
            pulumi.set(__self__, "action_to_trigger", action_to_trigger)
        if duration is not None:
            pulumi.set(__self__, "duration", duration)
        if escalation_chain_id is not None:
            pulumi.set(__self__, "escalation_chain_id", escalation_chain_id)
        if group_to_notify is not None:
            pulumi.set(__self__, "group_to_notify", group_to_notify)
        if important is not None:
            pulumi.set(__self__, "important", important)
        if notify_if_time_from is not None:
            pulumi.set(__self__, "notify_if_time_from", notify_if_time_from)
        if notify_if_time_to is not None:
            pulumi.set(__self__, "notify_if_time_to", notify_if_time_to)
        if notify_on_call_from_schedule is not None:
            pulumi.set(__self__, "notify_on_call_from_schedule", notify_on_call_from_schedule)
        if notify_to_team_members is not None:
            pulumi.set(__self__, "notify_to_team_members", notify_to_team_members)
        if persons_to_notifies is not None:
            pulumi.set(__self__, "persons_to_notifies", persons_to_notifies)
        if persons_to_notify_next_each_times is not None:
            pulumi.set(__self__, "persons_to_notify_next_each_times", persons_to_notify_next_each_times)
        if position is not None:
            pulumi.set(__self__, "position", position)
        if severity is not None:
            pulumi.set(__self__, "severity", severity)
        if type is not None:
            pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter(name="actionToTrigger")
    def action_to_trigger(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of an Action for trigger_webhook type step.
        """
        return pulumi.get(self, "action_to_trigger")

    @action_to_trigger.setter
    def action_to_trigger(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "action_to_trigger", value)

    @property
    @pulumi.getter
    def duration(self) -> Optional[pulumi.Input[int]]:
        """
        The duration of delay for wait type step. (60-86400) seconds
        """
        return pulumi.get(self, "duration")

    @duration.setter
    def duration(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "duration", value)

    @property
    @pulumi.getter(name="escalationChainId")
    def escalation_chain_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the escalation chain.
        """
        return pulumi.get(self, "escalation_chain_id")

    @escalation_chain_id.setter
    def escalation_chain_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "escalation_chain_id", value)

    @property
    @pulumi.getter(name="groupToNotify")
    def group_to_notify(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of a User Group for notify*user*group type step.
        """
        return pulumi.get(self, "group_to_notify")

    @group_to_notify.setter
    def group_to_notify(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "group_to_notify", value)

    @property
    @pulumi.getter
    def important(self) -> Optional[pulumi.Input[bool]]:
        """
        Will activate "important" personal notification rules. Actual for steps: notify*persons, notify*person*next*each*time, notify*on*call*from*schedule, notify*user*group and notify*team_members
        """
        return pulumi.get(self, "important")

    @important.setter
    def important(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "important", value)

    @property
    @pulumi.getter(name="notifyIfTimeFrom")
    def notify_if_time_from(self) -> Optional[pulumi.Input[str]]:
        """
        The beginning of the time interval for notify*if*time*from*to type step in UTC (for example 08:00:00Z).
        """
        return pulumi.get(self, "notify_if_time_from")

    @notify_if_time_from.setter
    def notify_if_time_from(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "notify_if_time_from", value)

    @property
    @pulumi.getter(name="notifyIfTimeTo")
    def notify_if_time_to(self) -> Optional[pulumi.Input[str]]:
        """
        The end of the time interval for notify*if*time*from*to type step in UTC (for example 18:00:00Z).
        """
        return pulumi.get(self, "notify_if_time_to")

    @notify_if_time_to.setter
    def notify_if_time_to(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "notify_if_time_to", value)

    @property
    @pulumi.getter(name="notifyOnCallFromSchedule")
    def notify_on_call_from_schedule(self) -> Optional[pulumi.Input[str]]:
        """
        ID of a Schedule for notify*on*call*from*schedule type step.
        """
        return pulumi.get(self, "notify_on_call_from_schedule")

    @notify_on_call_from_schedule.setter
    def notify_on_call_from_schedule(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "notify_on_call_from_schedule", value)

    @property
    @pulumi.getter(name="notifyToTeamMembers")
    def notify_to_team_members(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of a Team for a notify*team*members type step.
        """
        return pulumi.get(self, "notify_to_team_members")

    @notify_to_team_members.setter
    def notify_to_team_members(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "notify_to_team_members", value)

    @property
    @pulumi.getter(name="personsToNotifies")
    def persons_to_notifies(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        The list of ID's of users for notify_persons type step.
        """
        return pulumi.get(self, "persons_to_notifies")

    @persons_to_notifies.setter
    def persons_to_notifies(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "persons_to_notifies", value)

    @property
    @pulumi.getter(name="personsToNotifyNextEachTimes")
    def persons_to_notify_next_each_times(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        The list of ID's of users for notify*person*next*each*time type step.
        """
        return pulumi.get(self, "persons_to_notify_next_each_times")

    @persons_to_notify_next_each_times.setter
    def persons_to_notify_next_each_times(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "persons_to_notify_next_each_times", value)

    @property
    @pulumi.getter
    def position(self) -> Optional[pulumi.Input[int]]:
        """
        The position of the escalation step (starts from 0).
        """
        return pulumi.get(self, "position")

    @position.setter
    def position(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "position", value)

    @property
    @pulumi.getter
    def severity(self) -> Optional[pulumi.Input[str]]:
        """
        The severity of the incident for declare_incident type step.
        """
        return pulumi.get(self, "severity")

    @severity.setter
    def severity(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "severity", value)

    @property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[str]]:
        """
        The type of escalation policy. Can be wait, notify*persons, notify*person*next*each*time, notify*on*call*from*schedule, trigger*webhook, notify*user*group, resolve, notify*whole*channel, notify*if*time*from*to, repeat*escalation, notify*team*members, declare*incident
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "type", value)


warnings.warn("""grafana.index/oncallescalation.OncallEscalation has been deprecated in favor of grafana.oncall/escalation.Escalation""", DeprecationWarning)


class OncallEscalation(pulumi.CustomResource):
    warnings.warn("""grafana.index/oncallescalation.OncallEscalation has been deprecated in favor of grafana.oncall/escalation.Escalation""", DeprecationWarning)

    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 action_to_trigger: Optional[pulumi.Input[str]] = None,
                 duration: Optional[pulumi.Input[int]] = None,
                 escalation_chain_id: Optional[pulumi.Input[str]] = None,
                 group_to_notify: Optional[pulumi.Input[str]] = None,
                 important: Optional[pulumi.Input[bool]] = None,
                 notify_if_time_from: Optional[pulumi.Input[str]] = None,
                 notify_if_time_to: Optional[pulumi.Input[str]] = None,
                 notify_on_call_from_schedule: Optional[pulumi.Input[str]] = None,
                 notify_to_team_members: Optional[pulumi.Input[str]] = None,
                 persons_to_notifies: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 persons_to_notify_next_each_times: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 position: Optional[pulumi.Input[int]] = None,
                 severity: Optional[pulumi.Input[str]] = None,
                 type: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        * [Official documentation](https://grafana.com/docs/oncall/latest/configure/escalation-chains-and-routes/)
        * [HTTP API](https://grafana.com/docs/oncall/latest/oncall-api-reference/escalation_policies/)

        ## Import

        ```sh
        $ pulumi import grafana:index/oncallEscalation:OncallEscalation name "{{ id }}"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] action_to_trigger: The ID of an Action for trigger_webhook type step.
        :param pulumi.Input[int] duration: The duration of delay for wait type step. (60-86400) seconds
        :param pulumi.Input[str] escalation_chain_id: The ID of the escalation chain.
        :param pulumi.Input[str] group_to_notify: The ID of a User Group for notify*user*group type step.
        :param pulumi.Input[bool] important: Will activate "important" personal notification rules. Actual for steps: notify*persons, notify*person*next*each*time, notify*on*call*from*schedule, notify*user*group and notify*team_members
        :param pulumi.Input[str] notify_if_time_from: The beginning of the time interval for notify*if*time*from*to type step in UTC (for example 08:00:00Z).
        :param pulumi.Input[str] notify_if_time_to: The end of the time interval for notify*if*time*from*to type step in UTC (for example 18:00:00Z).
        :param pulumi.Input[str] notify_on_call_from_schedule: ID of a Schedule for notify*on*call*from*schedule type step.
        :param pulumi.Input[str] notify_to_team_members: The ID of a Team for a notify*team*members type step.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] persons_to_notifies: The list of ID's of users for notify_persons type step.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] persons_to_notify_next_each_times: The list of ID's of users for notify*person*next*each*time type step.
        :param pulumi.Input[int] position: The position of the escalation step (starts from 0).
        :param pulumi.Input[str] severity: The severity of the incident for declare_incident type step.
        :param pulumi.Input[str] type: The type of escalation policy. Can be wait, notify*persons, notify*person*next*each*time, notify*on*call*from*schedule, trigger*webhook, notify*user*group, resolve, notify*whole*channel, notify*if*time*from*to, repeat*escalation, notify*team*members, declare*incident
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: OncallEscalationArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        * [Official documentation](https://grafana.com/docs/oncall/latest/configure/escalation-chains-and-routes/)
        * [HTTP API](https://grafana.com/docs/oncall/latest/oncall-api-reference/escalation_policies/)

        ## Import

        ```sh
        $ pulumi import grafana:index/oncallEscalation:OncallEscalation name "{{ id }}"
        ```

        :param str resource_name: The name of the resource.
        :param OncallEscalationArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(OncallEscalationArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 action_to_trigger: Optional[pulumi.Input[str]] = None,
                 duration: Optional[pulumi.Input[int]] = None,
                 escalation_chain_id: Optional[pulumi.Input[str]] = None,
                 group_to_notify: Optional[pulumi.Input[str]] = None,
                 important: Optional[pulumi.Input[bool]] = None,
                 notify_if_time_from: Optional[pulumi.Input[str]] = None,
                 notify_if_time_to: Optional[pulumi.Input[str]] = None,
                 notify_on_call_from_schedule: Optional[pulumi.Input[str]] = None,
                 notify_to_team_members: Optional[pulumi.Input[str]] = None,
                 persons_to_notifies: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 persons_to_notify_next_each_times: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 position: Optional[pulumi.Input[int]] = None,
                 severity: Optional[pulumi.Input[str]] = None,
                 type: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        pulumi.log.warn("""OncallEscalation is deprecated: grafana.index/oncallescalation.OncallEscalation has been deprecated in favor of grafana.oncall/escalation.Escalation""")
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = OncallEscalationArgs.__new__(OncallEscalationArgs)

            __props__.__dict__["action_to_trigger"] = action_to_trigger
            __props__.__dict__["duration"] = duration
            if escalation_chain_id is None and not opts.urn:
                raise TypeError("Missing required property 'escalation_chain_id'")
            __props__.__dict__["escalation_chain_id"] = escalation_chain_id
            __props__.__dict__["group_to_notify"] = group_to_notify
            __props__.__dict__["important"] = important
            __props__.__dict__["notify_if_time_from"] = notify_if_time_from
            __props__.__dict__["notify_if_time_to"] = notify_if_time_to
            __props__.__dict__["notify_on_call_from_schedule"] = notify_on_call_from_schedule
            __props__.__dict__["notify_to_team_members"] = notify_to_team_members
            __props__.__dict__["persons_to_notifies"] = persons_to_notifies
            __props__.__dict__["persons_to_notify_next_each_times"] = persons_to_notify_next_each_times
            if position is None and not opts.urn:
                raise TypeError("Missing required property 'position'")
            __props__.__dict__["position"] = position
            __props__.__dict__["severity"] = severity
            if type is None and not opts.urn:
                raise TypeError("Missing required property 'type'")
            __props__.__dict__["type"] = type
        super(OncallEscalation, __self__).__init__(
            'grafana:index/oncallEscalation:OncallEscalation',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            action_to_trigger: Optional[pulumi.Input[str]] = None,
            duration: Optional[pulumi.Input[int]] = None,
            escalation_chain_id: Optional[pulumi.Input[str]] = None,
            group_to_notify: Optional[pulumi.Input[str]] = None,
            important: Optional[pulumi.Input[bool]] = None,
            notify_if_time_from: Optional[pulumi.Input[str]] = None,
            notify_if_time_to: Optional[pulumi.Input[str]] = None,
            notify_on_call_from_schedule: Optional[pulumi.Input[str]] = None,
            notify_to_team_members: Optional[pulumi.Input[str]] = None,
            persons_to_notifies: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            persons_to_notify_next_each_times: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            position: Optional[pulumi.Input[int]] = None,
            severity: Optional[pulumi.Input[str]] = None,
            type: Optional[pulumi.Input[str]] = None) -> 'OncallEscalation':
        """
        Get an existing OncallEscalation resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] action_to_trigger: The ID of an Action for trigger_webhook type step.
        :param pulumi.Input[int] duration: The duration of delay for wait type step. (60-86400) seconds
        :param pulumi.Input[str] escalation_chain_id: The ID of the escalation chain.
        :param pulumi.Input[str] group_to_notify: The ID of a User Group for notify*user*group type step.
        :param pulumi.Input[bool] important: Will activate "important" personal notification rules. Actual for steps: notify*persons, notify*person*next*each*time, notify*on*call*from*schedule, notify*user*group and notify*team_members
        :param pulumi.Input[str] notify_if_time_from: The beginning of the time interval for notify*if*time*from*to type step in UTC (for example 08:00:00Z).
        :param pulumi.Input[str] notify_if_time_to: The end of the time interval for notify*if*time*from*to type step in UTC (for example 18:00:00Z).
        :param pulumi.Input[str] notify_on_call_from_schedule: ID of a Schedule for notify*on*call*from*schedule type step.
        :param pulumi.Input[str] notify_to_team_members: The ID of a Team for a notify*team*members type step.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] persons_to_notifies: The list of ID's of users for notify_persons type step.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] persons_to_notify_next_each_times: The list of ID's of users for notify*person*next*each*time type step.
        :param pulumi.Input[int] position: The position of the escalation step (starts from 0).
        :param pulumi.Input[str] severity: The severity of the incident for declare_incident type step.
        :param pulumi.Input[str] type: The type of escalation policy. Can be wait, notify*persons, notify*person*next*each*time, notify*on*call*from*schedule, trigger*webhook, notify*user*group, resolve, notify*whole*channel, notify*if*time*from*to, repeat*escalation, notify*team*members, declare*incident
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _OncallEscalationState.__new__(_OncallEscalationState)

        __props__.__dict__["action_to_trigger"] = action_to_trigger
        __props__.__dict__["duration"] = duration
        __props__.__dict__["escalation_chain_id"] = escalation_chain_id
        __props__.__dict__["group_to_notify"] = group_to_notify
        __props__.__dict__["important"] = important
        __props__.__dict__["notify_if_time_from"] = notify_if_time_from
        __props__.__dict__["notify_if_time_to"] = notify_if_time_to
        __props__.__dict__["notify_on_call_from_schedule"] = notify_on_call_from_schedule
        __props__.__dict__["notify_to_team_members"] = notify_to_team_members
        __props__.__dict__["persons_to_notifies"] = persons_to_notifies
        __props__.__dict__["persons_to_notify_next_each_times"] = persons_to_notify_next_each_times
        __props__.__dict__["position"] = position
        __props__.__dict__["severity"] = severity
        __props__.__dict__["type"] = type
        return OncallEscalation(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="actionToTrigger")
    def action_to_trigger(self) -> pulumi.Output[Optional[str]]:
        """
        The ID of an Action for trigger_webhook type step.
        """
        return pulumi.get(self, "action_to_trigger")

    @property
    @pulumi.getter
    def duration(self) -> pulumi.Output[Optional[int]]:
        """
        The duration of delay for wait type step. (60-86400) seconds
        """
        return pulumi.get(self, "duration")

    @property
    @pulumi.getter(name="escalationChainId")
    def escalation_chain_id(self) -> pulumi.Output[str]:
        """
        The ID of the escalation chain.
        """
        return pulumi.get(self, "escalation_chain_id")

    @property
    @pulumi.getter(name="groupToNotify")
    def group_to_notify(self) -> pulumi.Output[Optional[str]]:
        """
        The ID of a User Group for notify*user*group type step.
        """
        return pulumi.get(self, "group_to_notify")

    @property
    @pulumi.getter
    def important(self) -> pulumi.Output[Optional[bool]]:
        """
        Will activate "important" personal notification rules. Actual for steps: notify*persons, notify*person*next*each*time, notify*on*call*from*schedule, notify*user*group and notify*team_members
        """
        return pulumi.get(self, "important")

    @property
    @pulumi.getter(name="notifyIfTimeFrom")
    def notify_if_time_from(self) -> pulumi.Output[Optional[str]]:
        """
        The beginning of the time interval for notify*if*time*from*to type step in UTC (for example 08:00:00Z).
        """
        return pulumi.get(self, "notify_if_time_from")

    @property
    @pulumi.getter(name="notifyIfTimeTo")
    def notify_if_time_to(self) -> pulumi.Output[Optional[str]]:
        """
        The end of the time interval for notify*if*time*from*to type step in UTC (for example 18:00:00Z).
        """
        return pulumi.get(self, "notify_if_time_to")

    @property
    @pulumi.getter(name="notifyOnCallFromSchedule")
    def notify_on_call_from_schedule(self) -> pulumi.Output[Optional[str]]:
        """
        ID of a Schedule for notify*on*call*from*schedule type step.
        """
        return pulumi.get(self, "notify_on_call_from_schedule")

    @property
    @pulumi.getter(name="notifyToTeamMembers")
    def notify_to_team_members(self) -> pulumi.Output[Optional[str]]:
        """
        The ID of a Team for a notify*team*members type step.
        """
        return pulumi.get(self, "notify_to_team_members")

    @property
    @pulumi.getter(name="personsToNotifies")
    def persons_to_notifies(self) -> pulumi.Output[Optional[Sequence[str]]]:
        """
        The list of ID's of users for notify_persons type step.
        """
        return pulumi.get(self, "persons_to_notifies")

    @property
    @pulumi.getter(name="personsToNotifyNextEachTimes")
    def persons_to_notify_next_each_times(self) -> pulumi.Output[Optional[Sequence[str]]]:
        """
        The list of ID's of users for notify*person*next*each*time type step.
        """
        return pulumi.get(self, "persons_to_notify_next_each_times")

    @property
    @pulumi.getter
    def position(self) -> pulumi.Output[int]:
        """
        The position of the escalation step (starts from 0).
        """
        return pulumi.get(self, "position")

    @property
    @pulumi.getter
    def severity(self) -> pulumi.Output[Optional[str]]:
        """
        The severity of the incident for declare_incident type step.
        """
        return pulumi.get(self, "severity")

    @property
    @pulumi.getter
    def type(self) -> pulumi.Output[str]:
        """
        The type of escalation policy. Can be wait, notify*persons, notify*person*next*each*time, notify*on*call*from*schedule, trigger*webhook, notify*user*group, resolve, notify*whole*channel, notify*if*time*from*to, repeat*escalation, notify*team*members, declare*incident
        """
        return pulumi.get(self, "type")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetServiceAccountResult',
    'AwaitableGetServiceAccountResult',
    'get_service_account',
    'get_service_account_output',
]

warnings.warn("""grafana.index/getserviceaccount.getServiceAccount has been deprecated in favor of grafana.oss/getserviceaccount.getServiceAccount""", DeprecationWarning)

@pulumi.output_type
class GetServiceAccountResult:
    """
    A collection of values returned by getServiceAccount.
    """
    def __init__(__self__, id=None, is_disabled=None, name=None, org_id=None, role=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if is_disabled and not isinstance(is_disabled, bool):
            raise TypeError("Expected argument 'is_disabled' to be a bool")
        pulumi.set(__self__, "is_disabled", is_disabled)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if org_id and not isinstance(org_id, str):
            raise TypeError("Expected argument 'org_id' to be a str")
        pulumi.set(__self__, "org_id", org_id)
        if role and not isinstance(role, str):
            raise TypeError("Expected argument 'role' to be a str")
        pulumi.set(__self__, "role", role)

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="isDisabled")
    def is_disabled(self) -> bool:
        """
        The disabled status for the service account.
        """
        return pulumi.get(self, "is_disabled")

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        The name of the Service Account.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[str]:
        """
        The Organization ID. If not set, the Org ID defined in the provider block will be used.
        """
        return pulumi.get(self, "org_id")

    @property
    @pulumi.getter
    def role(self) -> str:
        """
        The basic role of the service account in the organization.
        """
        return pulumi.get(self, "role")


class AwaitableGetServiceAccountResult(GetServiceAccountResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetServiceAccountResult(
            id=self.id,
            is_disabled=self.is_disabled,
            name=self.name,
            org_id=self.org_id,
            role=self.role)


def get_service_account(name: Optional[str] = None,
                        org_id: Optional[str] = None,
                        opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetServiceAccountResult:
    """
    * [Official documentation](https://grafana.com/docs/grafana/latest/administration/service-accounts/)
            * [HTTP API](https://grafana.com/docs/grafana/latest/developers/http_api/serviceaccount/#service-account-api)

    ## Example Usage

    ```python
    import pulumi
    import pulumi_grafana as grafana
    import pulumiverse_grafana as grafana

    admin_service_account = grafana.oss.ServiceAccount("admin",
        name="admin sa",
        role="Admin",
        is_disabled=False)
    admin = grafana.oss.get_service_account_output(name=admin_service_account.name)
    ```


    :param str name: The name of the Service Account.
    :param str org_id: The Organization ID. If not set, the Org ID defined in the provider block will be used.
    """
    pulumi.log.warn("""get_service_account is deprecated: grafana.index/getserviceaccount.getServiceAccount has been deprecated in favor of grafana.oss/getserviceaccount.getServiceAccount""")
    __args__ = dict()
    __args__['name'] = name
    __args__['orgId'] = org_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('grafana:index/getServiceAccount:getServiceAccount', __args__, opts=opts, typ=GetServiceAccountResult).value

    return AwaitableGetServiceAccountResult(
        id=pulumi.get(__ret__, 'id'),
        is_disabled=pulumi.get(__ret__, 'is_disabled'),
        name=pulumi.get(__ret__, 'name'),
        org_id=pulumi.get(__ret__, 'org_id'),
        role=pulumi.get(__ret__, 'role'))
def get_service_account_output(name: Optional[pulumi.Input[str]] = None,
                               org_id: Optional[pulumi.Input[Optional[str]]] = None,
                               opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetServiceAccountResult]:
    """
    * [Official documentation](https://grafana.com/docs/grafana/latest/administration/service-accounts/)
            * [HTTP API](https://grafana.com/docs/grafana/latest/developers/http_api/serviceaccount/#service-account-api)

    ## Example Usage

    ```python
    import pulumi
    import pulumi_grafana as grafana
    import pulumiverse_grafana as grafana

    admin_service_account = grafana.oss.ServiceAccount("admin",
        name="admin sa",
        role="Admin",
        is_disabled=False)
    admin = grafana.oss.get_service_account_output(name=admin_service_account.name)
    ```


    :param str name: The name of the Service Account.
    :param str org_id: The Organization ID. If not set, the Org ID defined in the provider block will be used.
    """
    pulumi.log.warn("""get_service_account is deprecated: grafana.index/getserviceaccount.getServiceAccount has been deprecated in favor of grafana.oss/getserviceaccount.getServiceAccount""")
    __args__ = dict()
    __args__['name'] = name
    __args__['orgId'] = org_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('grafana:index/getServiceAccount:getServiceAccount', __args__, opts=opts, typ=GetServiceAccountResult)
    return __ret__.apply(lambda __response__: GetServiceAccountResult(
        id=pulumi.get(__response__, 'id'),
        is_disabled=pulumi.get(__response__, 'is_disabled'),
        name=pulumi.get(__response__, 'name'),
        org_id=pulumi.get(__response__, 'org_id'),
        role=pulumi.get(__response__, 'role')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['AnnotationArgs', 'Annotation']

@pulumi.input_type
class AnnotationArgs:
    def __init__(__self__, *,
                 text: pulumi.Input[str],
                 dashboard_uid: Optional[pulumi.Input[str]] = None,
                 org_id: Optional[pulumi.Input[str]] = None,
                 panel_id: Optional[pulumi.Input[int]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 time: Optional[pulumi.Input[str]] = None,
                 time_end: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a Annotation resource.
        :param pulumi.Input[str] text: The text to associate with the annotation.
        :param pulumi.Input[str] dashboard_uid: The UID of the dashboard on which to create the annotation.
        :param pulumi.Input[str] org_id: The Organization ID. If not set, the Org ID defined in the provider block will be used.
        :param pulumi.Input[int] panel_id: The ID of the dashboard panel on which to create the annotation.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] tags: The tags to associate with the annotation.
        :param pulumi.Input[str] time: The RFC 3339-formatted time string indicating the annotation's time.
        :param pulumi.Input[str] time_end: The RFC 3339-formatted time string indicating the annotation's end time.
        """
        pulumi.set(__self__, "text", text)
        if dashboard_uid is not None:
            pulumi.set(__self__, "dashboard_uid", dashboard_uid)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if panel_id is not None:
            pulumi.set(__self__, "panel_id", panel_id)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if time is not None:
            pulumi.set(__self__, "time", time)
        if time_end is not None:
            pulumi.set(__self__, "time_end", time_end)

    @property
    @pulumi.getter
    def text(self) -> pulumi.Input[str]:
        """
        The text to associate with the annotation.
        """
        return pulumi.get(self, "text")

    @text.setter
    def text(self, value: pulumi.Input[str]):
        pulumi.set(self, "text", value)

    @property
    @pulumi.getter(name="dashboardUid")
    def dashboard_uid(self) -> Optional[pulumi.Input[str]]:
        """
        The UID of the dashboard on which to create the annotation.
        """
        return pulumi.get(self, "dashboard_uid")

    @dashboard_uid.setter
    def dashboard_uid(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "dashboard_uid", value)

    @property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[str]]:
        """
        The Organization ID. If not set, the Org ID defined in the provider block will be used.
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "org_id", value)

    @property
    @pulumi.getter(name="panelId")
    def panel_id(self) -> Optional[pulumi.Input[int]]:
        """
        The ID of the dashboard panel on which to create the annotation.
        """
        return pulumi.get(self, "panel_id")

    @panel_id.setter
    def panel_id(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "panel_id", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        The tags to associate with the annotation.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter
    def time(self) -> Optional[pulumi.Input[str]]:
        """
        The RFC 3339-formatted time string indicating the annotation's time.
        """
        return pulumi.get(self, "time")

    @time.setter
    def time(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "time", value)

    @property
    @pulumi.getter(name="timeEnd")
    def time_end(self) -> Optional[pulumi.Input[str]]:
        """
        The RFC 3339-formatted time string indicating the annotation's end time.
        """
        return pulumi.get(self, "time_end")

    @time_end.setter
    def time_end(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "time_end", value)


@pulumi.input_type
class _AnnotationState:
    def __init__(__self__, *,
                 dashboard_uid: Optional[pulumi.Input[str]] = None,
                 org_id: Optional[pulumi.Input[str]] = None,
                 panel_id: Optional[pulumi.Input[int]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 text: Optional[pulumi.Input[str]] = None,
                 time: Optional[pulumi.Input[str]] = None,
                 time_end: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering Annotation resources.
        :param pulumi.Input[str] dashboard_uid: The UID of the dashboard on which to create the annotation.
        :param pulumi.Input[str] org_id: The Organization ID. If not set, the Org ID defined in the provider block will be used.
        :param pulumi.Input[int] panel_id: The ID of the dashboard panel on which to create the annotation.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] tags: The tags to associate with the annotation.
        :param pulumi.Input[str] text: The text to associate with the annotation.
        :param pulumi.Input[str] time: The RFC 3339-formatted time string indicating the annotation's time.
        :param pulumi.Input[str] time_end: The RFC 3339-formatted time string indicating the annotation's end time.
        """
        if dashboard_uid is not None:
            pulumi.set(__self__, "dashboard_uid", dashboard_uid)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if panel_id is not None:
            pulumi.set(__self__, "panel_id", panel_id)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if text is not None:
            pulumi.set(__self__, "text", text)
        if time is not None:
            pulumi.set(__self__, "time", time)
        if time_end is not None:
            pulumi.set(__self__, "time_end", time_end)

    @property
    @pulumi.getter(name="dashboardUid")
    def dashboard_uid(self) -> Optional[pulumi.Input[str]]:
        """
        The UID of the dashboard on which to create the annotation.
        """
        return pulumi.get(self, "dashboard_uid")

    @dashboard_uid.setter
    def dashboard_uid(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "dashboard_uid", value)

    @property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[str]]:
        """
        The Organization ID. If not set, the Org ID defined in the provider block will be used.
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "org_id", value)

    @property
    @pulumi.getter(name="panelId")
    def panel_id(self) -> Optional[pulumi.Input[int]]:
        """
        The ID of the dashboard panel on which to create the annotation.
        """
        return pulumi.get(self, "panel_id")

    @panel_id.setter
    def panel_id(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "panel_id", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        The tags to associate with the annotation.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter
    def text(self) -> Optional[pulumi.Input[str]]:
        """
        The text to associate with the annotation.
        """
        return pulumi.get(self, "text")

    @text.setter
    def text(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "text", value)

    @property
    @pulumi.getter
    def time(self) -> Optional[pulumi.Input[str]]:
        """
        The RFC 3339-formatted time string indicating the annotation's time.
        """
        return pulumi.get(self, "time")

    @time.setter
    def time(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "time", value)

    @property
    @pulumi.getter(name="timeEnd")
    def time_end(self) -> Optional[pulumi.Input[str]]:
        """
        The RFC 3339-formatted time string indicating the annotation's end time.
        """
        return pulumi.get(self, "time_end")

    @time_end.setter
    def time_end(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "time_end", value)


warnings.warn("""grafana.index/annotation.Annotation has been deprecated in favor of grafana.oss/annotation.Annotation""", DeprecationWarning)


class Annotation(pulumi.CustomResource):
    warnings.warn("""grafana.index/annotation.Annotation has been deprecated in favor of grafana.oss/annotation.Annotation""", DeprecationWarning)

    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 dashboard_uid: Optional[pulumi.Input[str]] = None,
                 org_id: Optional[pulumi.Input[str]] = None,
                 panel_id: Optional[pulumi.Input[int]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 text: Optional[pulumi.Input[str]] = None,
                 time: Optional[pulumi.Input[str]] = None,
                 time_end: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        * [Official documentation](https://grafana.com/docs/grafana/latest/dashboards/build-dashboards/annotate-visualizations/)
        * [HTTP API](https://grafana.com/docs/grafana/latest/developers/http_api/annotations/)

        ## Example Usage

        ```python
        import pulumi
        import pulumiverse_grafana as grafana

        test = grafana.oss.Annotation("test", text="basic text")
        ```

        ## Import

        ```sh
        $ pulumi import grafana:index/annotation:Annotation name "{{ id }}"
        ```

        ```sh
        $ pulumi import grafana:index/annotation:Annotation name "{{ orgID }}:{{ id }}"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] dashboard_uid: The UID of the dashboard on which to create the annotation.
        :param pulumi.Input[str] org_id: The Organization ID. If not set, the Org ID defined in the provider block will be used.
        :param pulumi.Input[int] panel_id: The ID of the dashboard panel on which to create the annotation.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] tags: The tags to associate with the annotation.
        :param pulumi.Input[str] text: The text to associate with the annotation.
        :param pulumi.Input[str] time: The RFC 3339-formatted time string indicating the annotation's time.
        :param pulumi.Input[str] time_end: The RFC 3339-formatted time string indicating the annotation's end time.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: AnnotationArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        * [Official documentation](https://grafana.com/docs/grafana/latest/dashboards/build-dashboards/annotate-visualizations/)
        * [HTTP API](https://grafana.com/docs/grafana/latest/developers/http_api/annotations/)

        ## Example Usage

        ```python
        import pulumi
        import pulumiverse_grafana as grafana

        test = grafana.oss.Annotation("test", text="basic text")
        ```

        ## Import

        ```sh
        $ pulumi import grafana:index/annotation:Annotation name "{{ id }}"
        ```

        ```sh
        $ pulumi import grafana:index/annotation:Annotation name "{{ orgID }}:{{ id }}"
        ```

        :param str resource_name: The name of the resource.
        :param AnnotationArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(AnnotationArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 dashboard_uid: Optional[pulumi.Input[str]] = None,
                 org_id: Optional[pulumi.Input[str]] = None,
                 panel_id: Optional[pulumi.Input[int]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 text: Optional[pulumi.Input[str]] = None,
                 time: Optional[pulumi.Input[str]] = None,
                 time_end: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        pulumi.log.warn("""Annotation is deprecated: grafana.index/annotation.Annotation has been deprecated in favor of grafana.oss/annotation.Annotation""")
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = AnnotationArgs.__new__(AnnotationArgs)

            __props__.__dict__["dashboard_uid"] = dashboard_uid
            __props__.__dict__["org_id"] = org_id
            __props__.__dict__["panel_id"] = panel_id
            __props__.__dict__["tags"] = tags
            if text is None and not opts.urn:
                raise TypeError("Missing required property 'text'")
            __props__.__dict__["text"] = text
            __props__.__dict__["time"] = time
            __props__.__dict__["time_end"] = time_end
        alias_opts = pulumi.ResourceOptions(aliases=[pulumi.Alias(type_="grafana:index/annotation:Annotation")])
        opts = pulumi.ResourceOptions.merge(opts, alias_opts)
        super(Annotation, __self__).__init__(
            'grafana:index/annotation:Annotation',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            dashboard_uid: Optional[pulumi.Input[str]] = None,
            org_id: Optional[pulumi.Input[str]] = None,
            panel_id: Optional[pulumi.Input[int]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            text: Optional[pulumi.Input[str]] = None,
            time: Optional[pulumi.Input[str]] = None,
            time_end: Optional[pulumi.Input[str]] = None) -> 'Annotation':
        """
        Get an existing Annotation resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] dashboard_uid: The UID of the dashboard on which to create the annotation.
        :param pulumi.Input[str] org_id: The Organization ID. If not set, the Org ID defined in the provider block will be used.
        :param pulumi.Input[int] panel_id: The ID of the dashboard panel on which to create the annotation.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] tags: The tags to associate with the annotation.
        :param pulumi.Input[str] text: The text to associate with the annotation.
        :param pulumi.Input[str] time: The RFC 3339-formatted time string indicating the annotation's time.
        :param pulumi.Input[str] time_end: The RFC 3339-formatted time string indicating the annotation's end time.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _AnnotationState.__new__(_AnnotationState)

        __props__.__dict__["dashboard_uid"] = dashboard_uid
        __props__.__dict__["org_id"] = org_id
        __props__.__dict__["panel_id"] = panel_id
        __props__.__dict__["tags"] = tags
        __props__.__dict__["text"] = text
        __props__.__dict__["time"] = time
        __props__.__dict__["time_end"] = time_end
        return Annotation(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="dashboardUid")
    def dashboard_uid(self) -> pulumi.Output[Optional[str]]:
        """
        The UID of the dashboard on which to create the annotation.
        """
        return pulumi.get(self, "dashboard_uid")

    @property
    @pulumi.getter(name="orgId")
    def org_id(self) -> pulumi.Output[Optional[str]]:
        """
        The Organization ID. If not set, the Org ID defined in the provider block will be used.
        """
        return pulumi.get(self, "org_id")

    @property
    @pulumi.getter(name="panelId")
    def panel_id(self) -> pulumi.Output[Optional[int]]:
        """
        The ID of the dashboard panel on which to create the annotation.
        """
        return pulumi.get(self, "panel_id")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Sequence[str]]]:
        """
        The tags to associate with the annotation.
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter
    def text(self) -> pulumi.Output[str]:
        """
        The text to associate with the annotation.
        """
        return pulumi.get(self, "text")

    @property
    @pulumi.getter
    def time(self) -> pulumi.Output[str]:
        """
        The RFC 3339-formatted time string indicating the annotation's time.
        """
        return pulumi.get(self, "time")

    @property
    @pulumi.getter(name="timeEnd")
    def time_end(self) -> pulumi.Output[str]:
        """
        The RFC 3339-formatted time string indicating the annotation's end time.
        """
        return pulumi.get(self, "time_end")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['FolderPermissionArgs', 'FolderPermission']

@pulumi.input_type
class FolderPermissionArgs:
    def __init__(__self__, *,
                 folder_uid: pulumi.Input[str],
                 org_id: Optional[pulumi.Input[str]] = None,
                 permissions: Optional[pulumi.Input[Sequence[pulumi.Input['FolderPermissionPermissionArgs']]]] = None):
        """
        The set of arguments for constructing a FolderPermission resource.
        :param pulumi.Input[str] folder_uid: The UID of the folder.
        :param pulumi.Input[str] org_id: The Organization ID. If not set, the Org ID defined in the provider block will be used.
        :param pulumi.Input[Sequence[pulumi.Input['FolderPermissionPermissionArgs']]] permissions: The permission items to add/update. Items that are omitted from the list will be removed.
        """
        pulumi.set(__self__, "folder_uid", folder_uid)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if permissions is not None:
            pulumi.set(__self__, "permissions", permissions)

    @property
    @pulumi.getter(name="folderUid")
    def folder_uid(self) -> pulumi.Input[str]:
        """
        The UID of the folder.
        """
        return pulumi.get(self, "folder_uid")

    @folder_uid.setter
    def folder_uid(self, value: pulumi.Input[str]):
        pulumi.set(self, "folder_uid", value)

    @property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[str]]:
        """
        The Organization ID. If not set, the Org ID defined in the provider block will be used.
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "org_id", value)

    @property
    @pulumi.getter
    def permissions(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['FolderPermissionPermissionArgs']]]]:
        """
        The permission items to add/update. Items that are omitted from the list will be removed.
        """
        return pulumi.get(self, "permissions")

    @permissions.setter
    def permissions(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['FolderPermissionPermissionArgs']]]]):
        pulumi.set(self, "permissions", value)


@pulumi.input_type
class _FolderPermissionState:
    def __init__(__self__, *,
                 folder_uid: Optional[pulumi.Input[str]] = None,
                 org_id: Optional[pulumi.Input[str]] = None,
                 permissions: Optional[pulumi.Input[Sequence[pulumi.Input['FolderPermissionPermissionArgs']]]] = None):
        """
        Input properties used for looking up and filtering FolderPermission resources.
        :param pulumi.Input[str] folder_uid: The UID of the folder.
        :param pulumi.Input[str] org_id: The Organization ID. If not set, the Org ID defined in the provider block will be used.
        :param pulumi.Input[Sequence[pulumi.Input['FolderPermissionPermissionArgs']]] permissions: The permission items to add/update. Items that are omitted from the list will be removed.
        """
        if folder_uid is not None:
            pulumi.set(__self__, "folder_uid", folder_uid)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if permissions is not None:
            pulumi.set(__self__, "permissions", permissions)

    @property
    @pulumi.getter(name="folderUid")
    def folder_uid(self) -> Optional[pulumi.Input[str]]:
        """
        The UID of the folder.
        """
        return pulumi.get(self, "folder_uid")

    @folder_uid.setter
    def folder_uid(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "folder_uid", value)

    @property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[str]]:
        """
        The Organization ID. If not set, the Org ID defined in the provider block will be used.
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "org_id", value)

    @property
    @pulumi.getter
    def permissions(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['FolderPermissionPermissionArgs']]]]:
        """
        The permission items to add/update. Items that are omitted from the list will be removed.
        """
        return pulumi.get(self, "permissions")

    @permissions.setter
    def permissions(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['FolderPermissionPermissionArgs']]]]):
        pulumi.set(self, "permissions", value)


warnings.warn("""grafana.index/folderpermission.FolderPermission has been deprecated in favor of grafana.oss/folderpermission.FolderPermission""", DeprecationWarning)


class FolderPermission(pulumi.CustomResource):
    warnings.warn("""grafana.index/folderpermission.FolderPermission has been deprecated in favor of grafana.oss/folderpermission.FolderPermission""", DeprecationWarning)

    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 folder_uid: Optional[pulumi.Input[str]] = None,
                 org_id: Optional[pulumi.Input[str]] = None,
                 permissions: Optional[pulumi.Input[Sequence[pulumi.Input[Union['FolderPermissionPermissionArgs', 'FolderPermissionPermissionArgsDict']]]]] = None,
                 __props__=None):
        """
        Manages the entire set of permissions for a folder. Permissions that aren't specified when applying this resource will be removed.
        * [Official documentation](https://grafana.com/docs/grafana/latest/administration/roles-and-permissions/access-control/)
        * [HTTP API](https://grafana.com/docs/grafana/latest/developers/http_api/folder_permissions/)

        ## Example Usage

        ```python
        import pulumi
        import pulumiverse_grafana as grafana

        team = grafana.oss.Team("team", name="Team Name")
        user = grafana.oss.User("user",
            email="user.name@example.com",
            login="user.name",
            password="my-password")
        collection = grafana.oss.Folder("collection", title="Folder Title")
        collection_permission = grafana.oss.FolderPermission("collectionPermission",
            folder_uid=collection.uid,
            permissions=[
                {
                    "role": "Editor",
                    "permission": "Edit",
                },
                {
                    "team_id": team.id,
                    "permission": "View",
                },
                {
                    "user_id": user.id,
                    "permission": "Admin",
                },
            ])
        ```

        ## Import

        ```sh
        $ pulumi import grafana:index/folderPermission:FolderPermission name "{{ folderUID }}"
        ```

        ```sh
        $ pulumi import grafana:index/folderPermission:FolderPermission name "{{ orgID }}:{{ folderUID }}"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] folder_uid: The UID of the folder.
        :param pulumi.Input[str] org_id: The Organization ID. If not set, the Org ID defined in the provider block will be used.
        :param pulumi.Input[Sequence[pulumi.Input[Union['FolderPermissionPermissionArgs', 'FolderPermissionPermissionArgsDict']]]] permissions: The permission items to add/update. Items that are omitted from the list will be removed.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: FolderPermissionArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages the entire set of permissions for a folder. Permissions that aren't specified when applying this resource will be removed.
        * [Official documentation](https://grafana.com/docs/grafana/latest/administration/roles-and-permissions/access-control/)
        * [HTTP API](https://grafana.com/docs/grafana/latest/developers/http_api/folder_permissions/)

        ## Example Usage

        ```python
        import pulumi
        import pulumiverse_grafana as grafana

        team = grafana.oss.Team("team", name="Team Name")
        user = grafana.oss.User("user",
            email="user.name@example.com",
            login="user.name",
            password="my-password")
        collection = grafana.oss.Folder("collection", title="Folder Title")
        collection_permission = grafana.oss.FolderPermission("collectionPermission",
            folder_uid=collection.uid,
            permissions=[
                {
                    "role": "Editor",
                    "permission": "Edit",
                },
                {
                    "team_id": team.id,
                    "permission": "View",
                },
                {
                    "user_id": user.id,
                    "permission": "Admin",
                },
            ])
        ```

        ## Import

        ```sh
        $ pulumi import grafana:index/folderPermission:FolderPermission name "{{ folderUID }}"
        ```

        ```sh
        $ pulumi import grafana:index/folderPermission:FolderPermission name "{{ orgID }}:{{ folderUID }}"
        ```

        :param str resource_name: The name of the resource.
        :param FolderPermissionArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(FolderPermissionArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 folder_uid: Optional[pulumi.Input[str]] = None,
                 org_id: Optional[pulumi.Input[str]] = None,
                 permissions: Optional[pulumi.Input[Sequence[pulumi.Input[Union['FolderPermissionPermissionArgs', 'FolderPermissionPermissionArgsDict']]]]] = None,
                 __props__=None):
        pulumi.log.warn("""FolderPermission is deprecated: grafana.index/folderpermission.FolderPermission has been deprecated in favor of grafana.oss/folderpermission.FolderPermission""")
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = FolderPermissionArgs.__new__(FolderPermissionArgs)

            if folder_uid is None and not opts.urn:
                raise TypeError("Missing required property 'folder_uid'")
            __props__.__dict__["folder_uid"] = folder_uid
            __props__.__dict__["org_id"] = org_id
            __props__.__dict__["permissions"] = permissions
        alias_opts = pulumi.ResourceOptions(aliases=[pulumi.Alias(type_="grafana:index/folderPermission:FolderPermission")])
        opts = pulumi.ResourceOptions.merge(opts, alias_opts)
        super(FolderPermission, __self__).__init__(
            'grafana:index/folderPermission:FolderPermission',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            folder_uid: Optional[pulumi.Input[str]] = None,
            org_id: Optional[pulumi.Input[str]] = None,
            permissions: Optional[pulumi.Input[Sequence[pulumi.Input[Union['FolderPermissionPermissionArgs', 'FolderPermissionPermissionArgsDict']]]]] = None) -> 'FolderPermission':
        """
        Get an existing FolderPermission resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] folder_uid: The UID of the folder.
        :param pulumi.Input[str] org_id: The Organization ID. If not set, the Org ID defined in the provider block will be used.
        :param pulumi.Input[Sequence[pulumi.Input[Union['FolderPermissionPermissionArgs', 'FolderPermissionPermissionArgsDict']]]] permissions: The permission items to add/update. Items that are omitted from the list will be removed.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _FolderPermissionState.__new__(_FolderPermissionState)

        __props__.__dict__["folder_uid"] = folder_uid
        __props__.__dict__["org_id"] = org_id
        __props__.__dict__["permissions"] = permissions
        return FolderPermission(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="folderUid")
    def folder_uid(self) -> pulumi.Output[str]:
        """
        The UID of the folder.
        """
        return pulumi.get(self, "folder_uid")

    @property
    @pulumi.getter(name="orgId")
    def org_id(self) -> pulumi.Output[Optional[str]]:
        """
        The Organization ID. If not set, the Org ID defined in the provider block will be used.
        """
        return pulumi.get(self, "org_id")

    @property
    @pulumi.getter
    def permissions(self) -> pulumi.Output[Optional[Sequence['outputs.FolderPermissionPermission']]]:
        """
        The permission items to add/update. Items that are omitted from the list will be removed.
        """
        return pulumi.get(self, "permissions")

